Module validators

Module validators 

Structs

ArticleFileData
Contents of an article file as well as path and matched entries.
ArticleFileDataUnverified
Contents of an article file as well as path and matched entries, but where some fields are unverified.
MatchedCitation
Citation from an article that has found a match in the source bibliography.
MatchedCitationDisambiguated
Citation from an article that has found a match in the source bibliography that also includes disambiguated author date String and year String.
Metadata
MetadataUnverified

Functions

verify_mdx_files
Verifies the integrity of MDX files. The function reads the MDX files, extracts metadata and markdown content, verifies the citations format, and matches the citations to the bibliography. The function returns a list of ArticleFileData structs containing the metadata, markdown content, matched citations, and full file content.