pub struct ArticleFileData {
pub path: String,
pub metadata: Metadata,
pub markdown_content: String,
pub entries_disambiguated: Vec<MatchedCitationDisambiguated>,
pub full_file_content: String,
}Expand description
Contents of an article file as well as path and matched entries.
Fields
path: StringPath to the file whose contents were extracted.
metadata: MetadataMetadata enclosed at the top of the file.
markdown_content: StringContents of the file.
entries_disambiguated: Vec<MatchedCitationDisambiguated>A set of citations that exist in the source .bib file with disambiguated author date and date.
full_file_content: StringOriginal contents of the file, includes metadata.